"use client"

import { Button } from "@/components/ui/button"
import { $createCodeNode } from "@lexical/code"
import { TOGGLE_LINK_COMMAND } from "@lexical/link"
import {
  INSERT_UNORDERED_LIST_COMMAND,
  REMOVE_LIST_COMMAND,
} from "@lexical/list"
import {
  useLexicalComposerContext,
} from "@lexical/react/LexicalComposerContext"
import {
  $createHeadingNode,
  $createQuoteNode,
} from "@lexical/rich-text"
import {
  $setBlocksType,
} from "@lexical/selection"
import {
  $createParagraphNode,
  $getSelection,
  $isRangeSelection,
  COMMAND_PRIORITY_CRITICAL,
  FORMAT_TEXT_COMMAND,
  SELECTION_CHANGE_COMMAND,
} from "lexical"
import { useEffect } from "react"

export default function ToolbarPlugin() {
  const [editor] = useLexicalComposerContext()

  useEffect(() => {
    return editor.registerCommand(
      SELECTION_CHANGE_COMMAND,
      () => {
        const selection = $getSelection()
        if ($isRangeSelection(selection)) {
          // You can optionally handle selection changes here.
        }
        return false
      },
      COMMAND_PRIORITY_CRITICAL
    )
  }, [editor])

  const format = (formatType: "bold" | "italic" | "underline" | "strikethrough") => {
    editor.dispatchCommand(FORMAT_TEXT_COMMAND, formatType)
  }

  const setHeading = (tag: "h1" | "h2" | "h3" | "paragraph") => {
    editor.update(() => {
      const selection = $getSelection()
      if ($isRangeSelection(selection)) {
        if (tag === "paragraph") {
          $setBlocksType(selection, () => $createParagraphNode())
        } else {
          $setBlocksType(selection, () => $createHeadingNode(tag))
        }
      }
    })
  }

  const insertQuote = () => {
    editor.update(() => {
      const selection = $getSelection()
      if ($isRangeSelection(selection)) {
        $setBlocksType(selection, () => $createQuoteNode())
      }
    })
  }

  const insertCodeBlock = () => {
    editor.update(() => {
      const selection = $getSelection()
      if ($isRangeSelection(selection)) {
        $setBlocksType(selection, () => $createCodeNode())
      }
    })
  }

  const insertBulletList = () => {
    editor.dispatchCommand(INSERT_UNORDERED_LIST_COMMAND, undefined)
  }

  const removeList = () => {
    editor.dispatchCommand(REMOVE_LIST_COMMAND, undefined)
  }

  const toggleLink = () => {
    editor.dispatchCommand(TOGGLE_LINK_COMMAND, {
      url: "https://example.com", // optional: replace with modal input
    })
  }

  return (
    <div className="flex flex-wrap gap-2 border-b pb-2 mb-2">
      <Button type="button" variant="outline" size="sm" onClick={() => format("bold")}>
        Bold
      </Button>
      <Button type="button" variant="outline" size="sm" onClick={() => format("italic")}>
        Italic
      </Button>
      <Button type="button" variant="outline" size="sm" onClick={() => format("underline")}>
        Underline
      </Button>
      <Button type="button" variant="outline" size="sm" onClick={() => format("strikethrough")}>
        Strike
      </Button>
      <Button type="button" variant="ghost" size="sm" onClick={() => setHeading("paragraph")}>
        P
      </Button>
      <Button type="button" variant="ghost" size="sm" onClick={() => setHeading("h1")}>
        H1
      </Button>
      <Button type="button" variant="ghost" size="sm" onClick={() => setHeading("h2")}>
        H2
      </Button>
      <Button type="button" variant="ghost" size="sm" onClick={() => setHeading("h3")}>
        H3
      </Button>
      <Button type="button" variant="outline" size="sm" onClick={insertBulletList}>
        • List
      </Button>
      <Button type="button" variant="outline" size="sm" onClick={removeList}>
        ⛔ List
      </Button>
      <Button type="button" variant="outline" size="sm" onClick={insertQuote}>
        “ Quote
      </Button>
      <Button type="button" variant="outline" size="sm" onClick={insertCodeBlock}>
        Code
      </Button>
      <Button type="button" variant="outline" size="sm" onClick={toggleLink}>
        🔗 Link
      </Button>
    </div>
  )
}
